package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.PublicConf;
import com.ruoyi.system.service.IPublicConfService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 外部公司配置Controller
 * 
 * @author 胡懿
 * @date 2025-03-25
 */
@RestController
@RequestMapping("/system/conf")
public class PublicConfController extends BaseController
{
    @Autowired
    private IPublicConfService publicConfService;

    /**
     * 查询外部公司配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:conf:list')")
    @GetMapping("/list")
    public TableDataInfo list(PublicConf publicConf)
    {
        startPage();
        List<PublicConf> list = publicConfService.selectPublicConfList(publicConf);
        return getDataTable(list);
    }

    /**
     * 导出外部公司配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:conf:export')")
    @Log(title = "外部公司配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PublicConf publicConf)
    {
        List<PublicConf> list = publicConfService.selectPublicConfList(publicConf);
        ExcelUtil<PublicConf> util = new ExcelUtil<PublicConf>(PublicConf.class);
        util.exportExcel(response, list, "外部公司配置数据");
    }

    /**
     * 获取外部公司配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:conf:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(publicConfService.selectPublicConfById(id));
    }

    /**
     * 新增外部公司配置
     */
    @PreAuthorize("@ss.hasPermi('system:conf:add')")
    @Log(title = "外部公司配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PublicConf publicConf)
    {
        return toAjax(publicConfService.insertPublicConf(publicConf));
    }

    /**
     * 修改外部公司配置
     */
    @PreAuthorize("@ss.hasPermi('system:conf:edit')")
    @Log(title = "外部公司配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PublicConf publicConf)
    {
        return toAjax(publicConfService.updatePublicConf(publicConf));
    }

    /**
     * 删除外部公司配置
     */
    @PreAuthorize("@ss.hasPermi('system:conf:remove')")
    @Log(title = "外部公司配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(publicConfService.deletePublicConfByIds(ids));
    }
}
