package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Model;
import com.ruoyi.system.domain.Prefix;
import com.ruoyi.system.mapper.ModelMapper;
import com.ruoyi.system.mapper.PrefixMapper;
import com.ruoyi.system.utils.BsjxUtils;
import com.ruoyi.system.utils.MyDateUtils;
import com.ruoyi.system.utils.SignAddInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.BsMapper;
import com.ruoyi.system.domain.Bs;
import com.ruoyi.system.service.IBsService;
import org.springframework.web.client.RestTemplate;

/**
 * 标识管理Service业务层处理
 * 
 * @author 胡懿
 * @date 2025-03-25
 */
@Service
public class BsServiceImpl implements IBsService 
{
    @Autowired
    private BsMapper bsMapper;
    @Autowired
    private ModelMapper modelMapper;
    @Autowired
    private PrefixMapper prefixMapper;

    /**
     * 查询标识管理
     * 
     * @param id 标识管理主键
     * @return 标识管理
     */
    @Override
    public Bs selectBsById(Long id)
    {
        return bsMapper.selectBsById(id);
    }

    /**
     * 查询标识管理列表
     * 
     * @param bs 标识管理
     * @return 标识管理
     */
    @Override
    public List<Bs> selectBsList(Bs bs)
    {
        return bsMapper.selectBsList(bs);
    }

    /**
     * 新增标识管理
     * 
     * @param bs 标识管理
     * @return 结果
     */
    @Override
    public int insertBs(Bs bs)
    {
        bs.setCreateTime(DateUtils.getNowDate());
        Prefix prefix = prefixMapper.findOne();
        String token = BsjxUtils.getToken(prefix.getUsername(), prefix.getPassword());
        SignAddInfo signAddInfo = JSONObject.parseObject(bs.getContentLine(), SignAddInfo.class);
        boolean b = BsjxUtils.addSign(token, signAddInfo);
        if (b) {
            return bsMapper.insertBs(bs);
        } else {
            return 0;
        }

    }

    /**
     * 修改标识管理
     * 
     * @param bs 标识管理
     * @return 结果
     */
    @Override
    public int updateBs(Bs bs)
    {
        bs.setUpdateTime(DateUtils.getNowDate());

        Prefix prefix = prefixMapper.findOne();
        String token = BsjxUtils.getToken(prefix.getUsername(), prefix.getPassword());
        SignAddInfo signAddInfo = JSONObject.parseObject(bs.getContentLine(), SignAddInfo.class);
        boolean b = BsjxUtils.updateSign(token, signAddInfo);
        if (b) {
            return bsMapper.updateBs(bs);
        } else {
            return 0;
        }
    }

    /**
     * 批量删除标识管理
     * 
     * @param ids 需要删除的标识管理主键
     * @return 结果
     */
    @Override
    public int deleteBsByIds(Long[] ids)
    {
        if (ids.length > 0) {
            for (long id : ids) {
                Bs bs = selectBsById(id);
                Prefix prefix = prefixMapper.findOne();
                String token = BsjxUtils.getToken(prefix.getUsername(), prefix.getPassword());
                SignAddInfo signAddInfo = new SignAddInfo();
                signAddInfo.setHandle(bs.getHandle());
                BsjxUtils.deleteSign(token, signAddInfo);
                bsMapper.deleteBsById(id);
            }

        }
        return 1;
    }

    /**
     * 删除标识管理信息
     * 
     * @param id 标识管理主键
     * @return 结果
     */
    @Override
    public int deleteBsById(Long id)
    {
        Bs bs = selectBsById(id);
        Prefix prefix = prefixMapper.findOne();
        String token = BsjxUtils.getToken(prefix.getUsername(), prefix.getPassword());
        SignAddInfo signAddInfo = new SignAddInfo();
        signAddInfo.setHandle(bs.getHandle());
        BsjxUtils.deleteSign(token, signAddInfo);
        return bsMapper.deleteBsById(id);
    }

    @Override
    public List<Bs> publicList(Bs bs) {
        return bsMapper.selectBsList(bs);
    }

    @Override
    public TableDataInfo getPublicList(String url, Bs bs,  Integer pageSize, Integer pageNum) {
        url += "?pageSize=" + pageSize;
        url += "&pageNum=" + pageNum;
        if (null != bs) {
            if (StringUtils.isNotBlank(bs.getHandle())){
                url += "&handle=" + bs.getHandle();
            }
            if (StringUtils.isNotBlank(bs.getModelName())){
                url += "&modelName=" + bs.getModelName();
            }
            if (null != bs.getModelId()){
                url += "&modelId=" + bs.getModelId();
            }
            if (StringUtils.isNotBlank(bs.getPrefix())){
                url += "&prefix=" + bs.getPrefix();
            }
        }

        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>("", headers);

        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.GET,
                entity,
                String.class);
        String body = response.getBody();

        TableDataInfo list = JSONObject.parseObject(body, TableDataInfo.class);

        return list;
    }
}
