package com.ruoyi.system.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.Prefix;
import com.ruoyi.system.mapper.PrefixMapper;
import com.ruoyi.system.utils.BsjxUPBody;
import com.ruoyi.system.utils.BsjxUtils;
import com.ruoyi.system.utils.SignInfo;
import com.sun.org.apache.xpath.internal.operations.Mod;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ModelMapper;
import com.ruoyi.system.domain.Model;
import com.ruoyi.system.service.IModelService;
import org.springframework.web.client.RestTemplate;

/**
 * 模版管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-25
 */
@Service
public class ModelServiceImpl implements IModelService 
{
    @Autowired
    private ModelMapper modelMapper;
    @Autowired
    private PrefixMapper prefixMapper;

    /**
     * 查询模版管理
     * 
     * @param id 模版管理主键
     * @return 模版管理
     */
    @Override
    public Model selectModelById(Long id)
    {
        return modelMapper.selectModelById(id);
    }

    /**
     * 查询模版管理列表
     * 
     * @param model 模版管理
     * @return 模版管理
     */
    @Override
    public List<Model> selectModelList(Model model)
    {
        return modelMapper.selectModelList(model);
    }

    /**
     * 新增模版管理
     * 
     * @param model 模版管理
     * @return 结果
     */
    @Override
    public int insertModel(Model model)
    {
        return modelMapper.insertModel(model);
    }

    /**
     * 修改模版管理
     * 
     * @param model 模版管理
     * @return 结果
     */
    @Override
    public int updateModel(Model model)
    {
        return modelMapper.updateModel(model);
    }

    /**
     * 批量删除模版管理
     * 
     * @param ids 需要删除的模版管理主键
     * @return 结果
     */
    @Override
    public int deleteModelByIds(Long[] ids)
    {
        return modelMapper.deleteModelByIds(ids);
    }

    /**
     * 删除模版管理信息
     * 
     * @param id 模版管理主键
     * @return 结果
     */
    @Override
    public int deleteModelById(Long id)
    {
        return modelMapper.deleteModelById(id);
    }

    @Override
    public Model getModelInfo(Long id) {
        Model model = selectModelById(id);
        Prefix prefix = prefixMapper.findOne();
        String token = BsjxUtils.getToken(prefix.getUsername(), prefix.getPassword());
        String dataTemplate = BsjxUtils.getDataTemplate(token, prefix.getPrefix(), model.getType());
        model.setDataTemplate(dataTemplate);
        return model;
    }

    @Override
    public List<Model> publicModelList(Model model) {
        return modelMapper.selectModelList(model);
    }

    @Override
    public TableDataInfo getPublicList(String url, Model model, Integer pageSize, Integer pageNum) {
        url += "?pageSize=" + pageSize;
        url += "&pageNum=" + pageNum;
        if (null != model) {
            if (StringUtils.isNotBlank(model.getName())){
                url += "&name=" + model.getName();
            }
            if (StringUtils.isNotBlank(model.getType())){
                url += "&type=" + model.getType();
            }
        }
        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_JSON);
        HttpEntity<String> entity = new HttpEntity<>("", headers);

        ResponseEntity<String> response = restTemplate.exchange(
                url,
                HttpMethod.GET,
                entity,
                String.class);
        String body = response.getBody();

        TableDataInfo list = JSONObject.parseObject(body, TableDataInfo.class);

        return list;
    }

}
